@@ -328,6 +328,9 @@ SERVICE_VERSIONS = {
     "live": [
         "2018-08-01"
     ],
+    "lowcode": [
+        "2021-01-08"
+    ],
     "lp": [
         "2020-02-24"
     ],
@@ -418,6 +421,9 @@ SERVICE_VERSIONS = {
     "ses": [
         "2020-10-02"
     ],
+    "smh": [
+        "2021-07-12"
+    ],
     "smpn": [
         "2019-08-22"
     ],
